@@ -168,7 +168,7 @@ sub value {
 	if (scalar(@_) > 1) {
 		${$_[0]}->[0] = defined $_[1] ? $_[1] : 0;
 	}
-	${$_[0]}->[0];
+	sprintf "%g", ${$_[0]}->[0];
 }
 
 sub unit {
@@ -179,7 +179,7 @@ sub unit {
 }
 
 sub stringify {
-	join '', @{${$_[0]}}
+	sprintf "%g%s", @{${$_[0]}};
 }
 
 sub equals {
